<?php
/**
 * @package WordPress
 * @subpackage vice
 * @version 1.0.0
 * Carousel design fields
*/

namespace ViceElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;


add_action('elementor/element/before_section_end', function( $section, $section_id, $args ) {

	if( $section_id == 'vice_elementor_section_carousel_global' ){
		$section->add_control(
			'items_per_row_desktop',
			[
				'label' => esc_html__( 'Items per row', 'vice-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'multiple' => false,
				'default' => '3',
				'options' =>[
					'1'=>'1','2'=>'2','3'=>'3','4'=>'4','5'=>'5','6'=>'6'
				]
			]
		);
		$section->add_control(
			'items_per_row_tablet',
			[
				'label' => esc_html__( 'Items per row tablet', 'vice-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'multiple' => false,
				'default' => '2',
				'options' =>[
					'1'=>'1','2'=>'2','3'=>'3','4'=>'4','5'=>'5','6'=>'6'
				]
			]
		);

		$section->add_control(
			'items_per_row_mobile',
			[
				'label' => esc_html__( 'Items per row mobile', 'vice-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'multiple' => false,
				'default' => '1',
				'options' =>[
					'1'=>'1','2'=>'2','3'=>'3','4'=>'4'
				]
			]
		);

		$section->add_control(
			'gap',
			[
				'label' => esc_html__( 'Gap', 'vice-elementor' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 30,
				'step' => 1,
				'default' => 15
			]
		);

		$section->add_control(
			'autoplay_timeout',
			[
				'label' => esc_html__( 'Autoplay timeout', 'vice-elementor' ),
				'description' => esc_html__( '0 = disabled', 'vice-elementor' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 60000,
				'step' => 1000,
				'default' => 4000
			]
		);

		$section->add_control(
			'pause_on_hover',
			[
				'label' => esc_html__( 'Pause on hover', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'return_value' => 'true',
			]
		);
		$section->add_control(
			'loop',
			[
				'label' => esc_html__( 'Loop', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'return_value' => 'true',
			]
		);
		$section->add_control(
			'center',
			[
				'label' => esc_html__( 'Center', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'return_value' => 'true',
			]
		);
		$section->add_control(
			'nav',
			[
				'label' => esc_html__( 'Arrows', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'vice-elementor' ),
				'label_off' => esc_html__('Hide', 'vice-elementor' ),
				'return_value' => 'true',
				'default' => 'true'
			]
		);
		$section->add_control(
			'dots',
			[
				'label' => esc_html__( 'Dots', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'vice-elementor' ),
				'label_off' => esc_html__('Hide', 'vice-elementor' ),
				'return_value' => 'true',
				'default' => 'true'
			]
		);

	}
}, 10, 3 );