<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Vice
 * @package  Elementor Vice
 * @version  1.0.0
 */


namespace ViceElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class ViceElementorButton extends Widget_Base {
	public function get_name() {
		return 'vice-elementor-button'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Button', 'elementor-vice' );
	}
	public function get_icon() {
		return 'vice-elementor-icons icon-prel-button';
	}
	public function get_categories() {
		return [ 'aaa-vice' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_button',
			[
				'label' => esc_html__( 'Button', 'elementor-vice' ),
			]
		);
			
			$this->add_control(
				'text',
				[
					'label' => esc_html__( 'Button label', 'elementor-vice' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__('Click here', 'elementor-vice')
				]
			);

			/**
			 * ====================
			 * chose function
			 * ====================
			 */
			$this->add_control(
				'vice_btnfn',
				[
					'label' => esc_html__( 'Function', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'link',
					'options' =>[
						'link' => esc_html__( "Link", "vice"),
						'playalbum' 	=>	esc_html__( "Play album", "elementor-vice"),
					]
				]
			);
				// Play album ====================== 

				$this->add_control(
					'include_by_id',
					[
						'label' => esc_html__( 'Album', 'elementor-vice' ),
						'type' => \Elementor\Controls_Manager::SELECT2,
						'label_block' => true,
						'multiple' => false,
						'options' => elementor_vice_autocomplete('release'),
						'condition' => [
							'vice_btnfn' => 'playalbum',
						],
					]
				);

				// OR link ====================== 
				$this->add_control(
					'link',
					[
						'label' => esc_html__( 'Button link', 'elementor-vice' ),
						'type' => Controls_Manager::TEXT,
						'condition' => [
							'vice_btnfn' => 'link',
						],
					]
				);
				$this->add_control(
					'target',
					[
						'label' => esc_html__( 'Button target', 'elementor-vice' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'multiple' => false,
						'options' =>[
							'' => esc_html__('Default', 'elementor-vice'),
							'_blank' => esc_html__('New tab', 'elementor-vice')
						],
						'condition' => [
							'vice_btnfn' => 'link',
						],
					]
				);
			// ==== function end ==========

			$this->add_control(
				'alignment',
				[
					'label' => esc_html__( 'Alignment', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						'' => esc_html__( "Default", "vice"),
						'alignleft' 	=>	esc_html__( "Left", "elementor-vice"),
						'alignright'	=>	esc_html__( "Right", "elementor-vice"),
						'aligncenter'	=>	esc_html__( "Center", "elementor-vice"),
					]
				]
			);

			$this->add_responsive_control(
				'btn-size',
				[
					'label' => esc_html__( 'Size', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 32,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 13,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .vice-btn' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'btn-padding',
				[
					'label' => esc_html__( 'Padding', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 32,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 8,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 8,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 8,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .vice-btn' => 'padding: {{SIZE}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'btn-radius',
				[
					'label' => esc_html__( 'Border-radius', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 32,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'tablet_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'mobile_default' => [
						'size' => 2,
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .vice-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
					],
				]
			);
			
			

		$this->end_controls_section();

		/**
		 * Colors
		 */
		$this->start_controls_section(
			'section_button_col',
			[
				'label' => esc_html__( 'Colors', 'elementor-vice' ),
			]
		);
			$this->add_control(
				'vice-btn-bg',
				[
					'label' => esc_html__( 'Background', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .vice-btn' => 'background-color: {{VALUE}} !important;',
					],
				]
			);
			$this->add_control(
				'vice-btn-txt',
				[
					'label' => esc_html__( 'Text color', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .vice-btn' => 'color: {{VALUE}} !important;',
					]
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border',
					'label' => __( 'Border', 'plugin-domain' ),
					'selector' => '{{WRAPPER}} .vice-btn',
				]
			);

			

		$this->end_controls_section();

		/**
		 * Colors hover
		 */
		$this->start_controls_section(
			'section_button_col_h',
			[
				'label' => esc_html__( 'Colors hover', 'elementor-vice' ),
			]
		);
			$this->add_control(
				'vice-btn-bgh',
				[
					'label' => esc_html__( 'Background hover', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .vice-btn:hover' => 'background-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'vice-btn-bch',
				[
					'label' => esc_html__( 'Border hover', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .vice-btn:hover' => 'border-color: {{VALUE}} !important;',
					]
				]
			);
			$this->add_control(
				'vice-btn-txthov',
				[
					'label' => esc_html__( 'Text color hover', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .vice-btn:hover' => 'color: {{VALUE}} !important;',
					]
				]
			);

		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		extract( shortcode_atts( array(
			'include_by_id' => false,
			'vice_btnfn' => 'link',
			'text' => esc_html__('Click here', 'vice'),
			'link' => '#',
			'target' => '',
			'alignment' => '',
		), $atts ) );
		$attributes = [];
		$noajax = '';
		if( $vice_btnfn == 'playalbum' && $include_by_id ){
			$id = $include_by_id;
			$link = get_the_permalink( $id );
			$attributes[] = 'data-addtoplaylyst';
			$attributes[] = 'data-releasedata="'. esc_js( add_query_arg( array('qw_get_json_data' => '1'), get_the_permalink( $id ) ) ).'"';
			$noajax = 'qwNoAjax';
		}
		if( $target == "_blank" ){
			$attributes[] = 'target="_blank"';
		}
		$attributes = implode(' ', $attributes);
		if( $alignment == 'aligncenter' || $alignment == 'center' ){ 
			?><p class="aligncenter"><?php 
		} 
			
			?><a href="<?php echo esc_attr( $link ); ?>" <?php echo $attributes; ?> class="btn vice-btn vice-btn--<?php  echo esc_attr( $alignment ); ?> <?php echo esc_attr( $noajax ); ?>"><span><?php echo esc_html($text); ?></span></a><?php 
		
		if($alignment == 'aligncenter'){ 
			?></p><?php 
		} 
	}
	
	protected function content_template() {}
}