<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Vice
 * @package  Elementor Vice
 * @version  1.0.0
 */


namespace ViceElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class ViceElementorCaption extends Widget_Base {
	public function get_name() {
		return 'vice-elementor-qt-caption'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Caption', 'vice-elementor' );
	}
	public function get_icon() {
		return 'vice-elementor-icons icon-prel-caption';
	}
	public function get_categories() {
		return [ 'aaa-vice' ]; // needs to be registered in _plugin.php
	}
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      // wp_register_script( 'vice-elementor-qt-caption', plugins_url( '/caption.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'vice-elementor-qt-caption' ];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_icons',
			[
				'label' => esc_html__( 'Caption', 'vice-elementor' ),
			]
		);
			$this->add_control(
				'vice_title',
				[
					'label' => esc_html__( 'Caption', 'vice-elementor' ),
					'default' => 'Caption',
					'type' => Controls_Manager::TEXT
				]
			);
			$this->add_control(
				'vice_decor',
				[
					'label' => esc_html__( 'Decoration', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						false 	=>	esc_html__( "None", 'vice-elementor'),
						'default' 	=>	esc_html__( "Default", 'vice-elementor'),
					]
				]
			);
			$this->add_control(
				'vice_fx',
				[
					'label' => esc_html__( 'Effect', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						'default' =>	esc_html__( "None", 'vice-elementor' ),
						"glitch" =>	esc_html__( "Glitch", 'vice-elementor' ),
					]
				]
			);
			$this->add_control(
				'vice_alignment',
				[
					'label' => esc_html__( 'Alignment', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'left',
					'options' =>[
						'default' 	=>	esc_html__( "Default", 'vice-elementor'),
						'center'	=>	esc_html__( "Center", 'vice-elementor'),
					]
				]
			);


			$this->add_control(
				'vice_customtypo',
				[
					'label' => esc_html__( 'Custom typography', 'vice-elementor' ),
					'type' => Controls_Manager::SWITCHER,
					'return_value' => '1',
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'vice_elementor_tupo',
					'label' => __( 'Typography','vice-elementor'),
					'scheme' => Typography::TYPOGRAPHY_1,

					'selector' => '{{WRAPPER}} .vice-elementor-caption--customtypo .vice-elementor-caption__txt',
					'condition' => [
						'vice_customtypo' => '1',
					],
				]
			);

	


		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		extract( shortcode_atts( array(
			'vice_decor' => false,
			'vice_customtypo' => false,
			'vice_fx' 		=> 'default',
			'vice_title' 	=> 'Caption',
			'vice_alignment'=> 'default',
		), $atts ) );

		$classes = array( 
			'vice-elementor-caption',
			'vice-elementor-caption--'.$vice_alignment
		);
		if( $vice_customtypo ){
			$classes[] = 'vice-elementor-caption--customtypo';	
		}
		if( $vice_decor ){
			$classes[] = 'vice-elementor-caption--'.$vice_decor;
		}
		$vice_title = wp_strip_all_tags( $vice_title );

		$fx_class = "vice-textfx-".$vice_fx;

		?>
		<div class="<?php echo esc_attr( implode(' ', $classes) ); ?>">
			<div class="vice-elementor-caption__c">
				<h2 class="vice-caption vice-elementor-caption__txt <?php echo esc_attr($fx_class); ?>" data-vice-textfx="<?php echo esc_attr( $vice_fx ); ?>"><?php echo esc_html( $vice_title ); ?></h2>
				<div class="vice-caption__decor" data-vice-textfx="<?php echo esc_attr( $vice_fx ); ?>"><hr></div>
			</div>
		</div>
		<?php
	}
	
	protected function content_template() {}
}