<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Vice
 * @package  Elementor Vice
 * @version  1.0.0
 */


namespace ViceElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/event-list-function.php' );

class ViceElementorEventList extends Widget_Base {
	public function get_name() {
		return 'vice-elementor-event-list'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Events list', 'vice-elementor' );
	}
	public function get_icon() {
		return 'vice-elementor-icons icon-prel-events-list';
	}
	public function get_categories() {
		return [ 'aaa-vice' ]; // needs to be registered in _plugin.php
	}

	// Javascript
	public function __construct($data = [], $args = null) {
	  parent::__construct($data, $args);
	  wp_register_script( 'vice-elementor-event-list', plugins_url( '/event-list.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
	}
	public function get_script_depends() {
		 return [ 'vice-elementor-event-list' ];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'vice_elementor_section_query_events',
			[
				'label' => esc_html__( 'Query', 'vice-elementor' ),
			]
		);	

			$this->add_control(
				'include_by_id',
				[
					'label' => esc_html__( 'Specific items by title', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => elementor_vice_autocomplete('event')
				]
			);
			$this->add_control(
				'items_per_page',
				[
					'label' => esc_html__( 'Max items', 'vice-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'min' => 1,
					'max' => 20,
					'step' => 1,
					'default' => 5
				]
			);
			$this->add_control(
				'tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => vice_elementor_get_terms_array('eventtype')
				]
			);
			$this->add_control(
				'query_event_filter',
				[
					'label' => esc_html__( 'Event filter', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						false => esc_html__( 'Any event', 'vice' ),
						'past' => esc_html__( 'Past events', 'vice' ),
						'next' => esc_html__( 'Next events', 'vice' ),
					],
				]
			);

			$this->add_control(
				'animation_3d',
				[
					'label' => esc_html__( '3D animation', 'vice-elementor' ),
					'type' => Controls_Manager::SWITCHER,
					'label_on' => esc_html__('Yes', 'vice-elementor' ),
					'label_off' => esc_html__('No', 'vice-elementor' ),
					'return_value' => 'true',
					'default' => false
				]
			);

			/**
			 * Cannot apply glitch to these items
			 */
			// $this->add_control(
			// 	'vice_fx',
			// 	[
			// 		'label' => esc_html__( 'Effect', 'vice-elementor' ),
			// 		'type' => \Elementor\Controls_Manager::SELECT,
			// 		'multiple' => false,
			// 		'options' =>[
			// 			'default' =>	esc_html__( "None", 'vice-elementor' ),
			// 			"glitch" =>	esc_html__( "Glitch", 'vice-elementor' ),
			// 		]
			// 	]
			// );
			
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('tax_filter', $atts)){
			if(is_array($atts['tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['tax_filter']);
			}
		}
		if(function_exists('vice_events_list')){
			echo vice_events_list( $atts );
		}
	}
	protected function content_template() {}
}