<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Vice
 * @package  Elementor Vice
 * @version  1.0.0
 */


namespace ViceElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/eventsmap-function.php' );

class ViceElementorEventMap extends Widget_Base {
	public function get_name() {
		return 'vice-elementor-events-map'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Events map', 'vice-elementor' );
	}
	public function get_icon() {
		return 'vice-elementor-icons eicon-google-maps';
	}
	public function get_categories() {
		return [ 'aaa-vice' ]; // needs to be registered in _plugin.php
	}

	// Javascript
	public function __construct($data = [], $args = null) {
	  parent::__construct($data, $args);
	  wp_register_script( 'vice-elementor-events-map', plugins_url( '/events-map.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
	}
	public function get_script_depends() {
		 return [ 'vice-elementor-events-map' ];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'vice_elementor_section_query_events',
			[
				'label' => esc_html__( 'Query', 'vice-elementor' ),
			]
		);	

		
			$this->add_control(
				'items_per_page',
				[
					'label' => esc_html__( 'Max items', 'vice-elementor' ),
					'type' => Controls_Manager::NUMBER,
					'min' => 1,
					'max' => 20,
					'step' => 1,
					'default' => 5
				]
			);
			
			$this->add_control(
				'hide_old',
				[
					'label' => esc_html__( 'Hide past events', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						0 => esc_html__( 'No', 'vice' ),
						1 => esc_html__( 'Yes', 'vice' ),
					],
				]
			);
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$api = get_theme_mod( 'QT_gmapsapi');
		if(!$api || '' === $api){
			echo 'Missing Google Maps API key in Appearance > Cusomize > Theme Options > General';
			return;
		}
		$atts = $this->get_settings_for_display();
		// if(array_key_exists('tax_filter', $atts)){
		// 	if(is_array($atts['tax_filter'])) {
		// 		$atts['tax_filter'] = implode(',', $atts['tax_filter']);
		// 	}
		// }
		if(function_exists('vice_elementor_events_map_display')){
			echo vice_elementor_events_map_display( $atts );
		}
	}
	protected function content_template() {}
}