<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Vice
 * @package  Elementor Vice
 * @version  1.0.0
 */


namespace ViceElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class ViceElementorFxPicture extends Widget_Base {
	public function get_name() {
		return 'vice-elementor-fxpicture'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'FX picture', 'vice-elementor' );
	}
	public function get_icon() {
		return 'vice-elementor-icons icon-prel-3d-header';
	}
	public function get_categories() {
		return [ 'aaa-vice' ]; // needs to be registered in _plugin.php
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_button',
			[
				'label' => esc_html__( 'Gallery', 'vice-elementor' ),
			]
		);	
			$this->add_control(
				'fxpicture',
				[
					'label' => esc_html__( 'Choose Image', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					]
				]
			);


			$this->add_responsive_control(
				'fxpicture-size',
				[
					'label' => esc_html__( 'Size', 'elementor-vice' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'range' => [
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'desktop_default' => [
						'size' => 30,
						'unit' => '%',
					],
					'tablet_default' => [
						'size' => 20,
						'unit' => '%',
					],
					'mobile_default' => [
						'size' => 10,
						'unit' => '%',
					],
					'selectors' => [
						'{{WRAPPER}} .vice-elementor-fxpicture__container' => 'max-width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'fx',
				[
					'label' => esc_html__( 'Effect', "elementor-vice" ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => false,
					'options' =>[
						false => esc_html__( "None", "elementor-vice"),
						"glitch" => esc_html__( "Glitch", "elementor-vice"),
					]
				]
			);
			$this->add_control(
				'imgalignment',
				[
					'label' => esc_html__( 'Align', "elementor-vice" ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'center',
					'options' =>[
						false => esc_html__( "None", "elementor-vice"),
						"center" => esc_html__( "Center", "elementor-vice"),
						"left" => esc_html__( "Left", "elementor-vice"),
						"right" => esc_html__( "Right", "elementor-vice"),
					]
				]
			);

			$this->add_control(
				'animation_3d',
				[
					'label' => esc_html__( '3D animation', 'vice-elementor' ),
					'type' => Controls_Manager::SWITCHER,
					'label_on' => esc_html__('Yes', 'vice-elementor' ),
					'label_off' => esc_html__('No', 'vice-elementor' ),
					'return_value' => 'true',
					'default' => false
				]
			);
		$this->end_controls_section();
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(!array_key_exists("fxpicture",$atts)){
			return;
		}
		$url = $atts['fxpicture']['url'];
		$classes = [];
		$vicefx = ( $atts['fx'] ) ? esc_attr( $atts['fx'] ) : '';
		if( $atts['imgalignment'] ){
			$classes[] = 'vice-elementor-fxpicture--'.$atts['imgalignment'];
		}
		$classes = implode(' ',$classes);
		?>
		<div class="vice-elementor-fxpicture <?php echo esc_attr($classes); ?>" data-vice-elementor-3dpicture="<?php echo esc_attr( $atts['animation_3d']  ); ?>">
			<div class="vice-elementor-fxpicture__container vice-imgfx--<?php echo esc_attr( $vicefx ); ?>" data-vice-elementor-3dpicture-content  data-vice-imgfx="<?php echo esc_attr( $vicefx ); ?>" data-vice-fx-activation="auto">
				<img src="<?php echo esc_attr( $url); ?>" class="vice-elementor-fxpicture__img">
			</div>
		</div>
		<?php
	}
	protected function content_template() {}
}