<?php
/**
 * @package WordPress
 * @subpackage vice
 * @version 1.0.0
 *
 * Example:
 * [qt-moderngallery post_type="" include_by_id="1,2,3" custom_query="..." tax_filter="category:trending, post_tag:video" items_per_page="9" orderby="date" order="DESC" meta_key="name_of_key" offset="" exclude="" el_class="" el_id=""]
*/


if(!function_exists( 'vice_template_moderngallery' )){
	function vice_template_moderngallery( $atts = array() ){

		

		/*
		 *	Defaults
		 * 	All parameters can be bypassed by same attribute in the shortcode
		 */
		extract( shortcode_atts( array(

			'vice_fx' 		=> 'default',
			'animation_3d' 	=> false,
			'itemsperrow' => false,

			// Gallery data
			'images'    => false,
			'gallery'    => false,
			'thumbsize' => 'thumbnail',
			'linksize'  => 'large',

			// 3DSlider parameters
			'items_per_row_desktop'	=> '3',
			'gap'					=> '15',
			'pause_on_hover'		=> 'true',
			'loop'					=> 'true',
			'center'				=> 'true',
			'nav'					=> 'true',
			'dots'					=> 'true',
			
			'stage_padding'			=> '0',
			'autoplay_timeout'		=> '4000',
			//tablet
			'items_per_row_tablet'	=> '2',
			//mobile
			'items_per_row_mobile'	=> '1',
			// Global parameters
			'el_id'					=> 'qt-moderngallery-'.uniqid( get_the_ID() ),
			'el_class'				=> '',
			'grid_id'				=> false // required for compatibility with WPBakery Page Builder
		), $atts ) );

		$grid_id = 'vice-elementor-moderngallery-grid-'.get_the_ID().'-'.md5( serialize($atts) );
		$el_id = 'vice-elementor-moderngallery-el-'.get_the_ID().'-'.md5( serialize($atts) );

		$images = array();

		if(is_array($atts)){
			if(array_key_exists("images", $atts)){
				$images = explode(',', $images);
			}
			// Alternative: gallery from Elementor
			if( $gallery ){
				if( count($gallery) > 0 ){
					$images = [];
					foreach( $gallery as $photo ){
						$images[] = $photo['id'];
					}
				}
			}
		}

		// Max results value, used in pagination
		$max = count($images);
		
		ob_start();

		if(count($images) > 0){ 
			$number = count($images);
			$current = 1;
			$container_classes = array('vice-elementor-owl-carousel-container', 'vice-modernslider', 'vice-modernslider--moderngallery');
			?>

			<div id="<?php echo esc_attr($grid_id); ?>" class="<?php echo esc_attr( implode(' ', $container_classes) ); ?>">
				<div id="<?php echo esc_attr($el_id); ?>" class="vice-elementor-owl-carousel owl-carousel owl-theme vice-elementor-owl-theme" 
					data-vice-animation3d="<?php echo esc_attr($animation_3d); ?>"
					data-vicefx="<?php echo esc_attr($vice_fx); ?>"
					data-indexslide="1"
					data-items="1"
					data-items_tablet="1"
					data-items_mobile="1"
					data-items_mobile_hori="1"
					data-gap="0"
					data-pause_on_hover="<?php 		echo esc_attr($pause_on_hover); ?>"
					data-loop="<?php 				echo esc_attr($loop); ?>" 
					data-center="<?php 				echo esc_attr($center); ?>" 
					data-stage_padding="<?php 		echo esc_attr($stage_padding); ?>"
					data-nav="<?php 				echo esc_attr($nav); ?>"
					data-dots="<?php 				echo esc_attr($dots); ?>" 
					data-autoplay_timeout="<?php 	echo esc_attr($autoplay_timeout); ?>" 
					data-amount="<?php 				echo esc_attr( $number ); ?>">
					<?php  
					foreach($images as $image){
						$thumb = wp_get_attachment_image_src($image, $thumbsize); 
						$link  = wp_get_attachment_image_src($image, $linksize);
						$thumb = $thumb[0];
						$link  = $link[0];

						set_query_var( 'slidenumber', $current );
						set_query_var( 'vicefx', $vice_fx );
						set_query_var( 'animation3d', $animation_3d );
						set_query_var( 'thumb', $thumb );
						set_query_var( 'link', $link );
						?>
						<div class="vice-elementor-item vice-3d-element" data-index="<?php echo esc_attr( $current ); ?>">
							<?php
							get_template_part ( 'template-parts/moderngallery/moderngallery-item');
							?>
						</div>
						<?php
						$current++;
					}
					?>
				</div>
			</div>
			<?php
		}
		
		return ob_get_clean();
	}
}