<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Vice
 * @package  Elementor Vice
 * @version  1.0.0
 */

namespace ViceElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/moderngallery-function.php' );
class ViceElementorModernGallery extends Widget_Base {
	public function get_name() {
		return 'vice-elementor-moderngallery'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Modern Gallery', 'vice-elementor' );
	}
	public function get_icon() {
		return 'vice-elementor-icons icon-prel-post-carouse';
	}
	public function get_categories() {
		return [ 'aaa-vice' ]; // needs to be registered in _plugin.php
	}
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'vice-elementor-moderngallery', plugins_url( '/moderngallery.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'vice-elementor-moderngallery' ];
	}
	protected function register_controls() {

		/**
		 * ======================================
		 * Section:
		 * Query parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'section_button',
			[
				'label' => esc_html__( 'Gallery', 'vice-elementor' ),
			]
		);	
			$this->add_control(
				'thumbsize',
				[
					'label' => esc_html__( 'Image size', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'm',
					'options' =>[
						'vice-squared-s' => esc_html__( "Squared small", "viceelementor"),
						'vice-squared-m' => esc_html__( "Squared medium", "viceelementor"),
						'thumbnail' => esc_html__( "Thumbnail", "viceelementor"),
						'medium' => esc_html__( "Medium", "viceelementor"),
						'large' => esc_html__( "Large", "viceelementor"),
					]
				]
			);
			$this->add_control(
				'linksize',
				[
					'label' => esc_html__( 'Linked size', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'default' => 'large',
					'options' =>[
						'medium' => esc_html__( "Medium", "viceelementor"),
						'large' => esc_html__( "Large", "viceelementor"),
						'full' => esc_html__( "Full", "viceelementor")
					]
				]
			);
			$this->add_control(
				'gallery',
				[
					'label' => esc_html__( 'Add Images', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::GALLERY,
				]
			);
		$this->end_controls_section();
		
		/**
		 * ======================================
		 * Section:
		 * 3DSlider parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'vice_elementor_section_modernslider',
			[
				'label' => esc_html__( 'Settings', 'vice-elementor' ),
			]
		);
		$this->add_control(
			'autoplay_timeout',
			[
				'label' => esc_html__( 'Autoplay timeout', 'vice-elementor' ),
				'description' => esc_html__( '0 = disabled', 'vice-elementor' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 80000,
				'step' => 1000,
				'default' => 4000
			]
		);

		$this->add_control(
			'pause_on_hover',
			[
				'label' => esc_html__( 'Pause on hover', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'true',
				'return_value' => 'true',
			]
		);
		$this->add_control(
			'loop',
			[
				'label' => esc_html__( 'Loop', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'true',
				'return_value' => 'true',
			]
		);
		
		$this->add_control(
			'nav',
			[
				'label' => esc_html__( 'Arrows', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'vice-elementor' ),
				'label_off' => esc_html__('Hide', 'vice-elementor' ),
				'return_value' => 'true',
				'default' => 'true'
			]
		);
		$this->add_control(
			'dots',
			[
				'label' => esc_html__( 'Dots', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'vice-elementor' ),
				'label_off' => esc_html__('Hide', 'vice-elementor' ),
				'return_value' => 'true',
				'default' => 'true'
			]
		);
		
		$this->add_control(
			'vice_fx',
			[
				'label' => esc_html__( 'Effect', 'vice-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'multiple' => false,
				'options' =>[
					'default' =>	esc_html__( "None", 'vice-elementor' ),
					"glitch" =>	esc_html__( "Glitch", 'vice-elementor' ),
				]
			]
		);

		$this->add_control(
			'animation_3d',
			[
				'label' => esc_html__( '3D animation', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Yes', 'vice-elementor' ),
				'label_off' => esc_html__('No', 'vice-elementor' ),
				'return_value' => 'true',
				'default' => false
			]
		);
		$this->end_controls_section();	
	}

	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('tax_filter', $atts)){
			if(is_array($atts['tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['tax_filter']);
			}
		}
		if(function_exists('vice_template_moderngallery')){
			echo vice_template_moderngallery( $atts );
		}
	}
	protected function content_template() {}
}