<?php
/**
 * @package WordPress
 * @subpackage vice
 * @version 1.0.0
 *
 * Example:
 * [qt-post-carousel post_type="" include_by_id="1,2,3" custom_query="..." tax_filter="category:trending, post_tag:video" items_per_page="9" orderby="date" order="DESC" meta_key="name_of_key" offset="" exclude="" el_class="" el_id=""]
*/


if(!function_exists( 'vice_template_post_carousel' )){
	function vice_template_post_carousel( $atts = array() ){

		
		/*
		 *	Defaults
		 * 	All parameters can be bypassed by same attribute in the shortcode
		 */
		extract( shortcode_atts( array(
			'animation_3d' => false,
			'id' => false, // Legacy parameter for retro compatibility 
			'quantity' => false, // Legacy parameter for retro compatibility 
			'posttype' => false, // Legacy parameter for retro compatibility 
			'category' => false, // Legacy parameter for retro compatibility 
			'itemsperrow' => false,

			// Query parameters
			'post_type' 			=> 'post',
			'query_event_filter'	=> false,
			'include_by_id'			=> false,
			'custom_query'			=> false,
			'tax_filter'			=> false,
			'items_per_page'		=> '9',
			'orderby'				=> 'date',
			'order'					=> 'DESC',
			'meta_key'				=> false,
			'offset'				=> 0,
			'exclude'				=> '',
			// Carousel parameters
			'items_per_row_desktop'	=> '3',
			'gap'					=> '15',
			'pause_on_hover'		=> 'true',
			'loop'					=> 'true',
			'center'				=> 'true',
			'nav'					=> 'true',
			'dots'					=> 'true',
			'stage_padding'			=> '0',
			'autoplay_timeout'		=> '4000',
			//tablet
			'items_per_row_tablet'	=> '2',
			//mobile
			'items_per_row_mobile'	=> '1',
			// Global parameters
			'el_id'					=> 'qt-post-carousel-'.uniqid( get_the_ID() ),
			'el_class'				=> '',
			'grid_id'				=> false // required for compatibility with WPBakery Page Builder
		), $atts ) );

		$grid_id = 'vice-elementor-post-carousel-grid-'.get_the_ID().'-'.md5( serialize($atts) );
		$el_id = 'vice-elementor-post-carousel-el-'.get_the_ID().'-'.md5( serialize($atts) );

		// ================================================
		// RETRO COMPATIBILITY

		/**
		 * Convert category into tax_filter
		 * @var  $category [string] category slug
		 */
		
		if ($category && 'all' !== $category && $tax_filter == false) {
			$tax_filter = 'category:'.$category;
		}

		// If an old post type parameter different from post was stored, let's use it
		if ( $posttype ) {
			$post_type = $posttype;
		}
		if( $id ){
			$include_by_id = $id;
		}
		if ($quantity) {
			$items_per_page = $quantity;
		}
		// END OF RETRO COMPATIBILITY
		// ================================================

		$paged = 1;

		include( 'query-prep.php' );

		$wp_query = new WP_Query( $args );
		// Max results value, used in pagination
		$max = $wp_query->max_num_pages;
		
		switch($post_type){
			case "release":
				$item_template = 'post-release';
				break;
			case "artist":
				$item_template = 'post-artist';
				break;
			case "members":
				$item_template = 'post-members';
				break;
			case "product":
				$item_template = 'post-product';
				break;
			case "podcast":
				$item_template = 'post-podcast';
				break;
			case "event":
				$item_template = 'post-event--card';
				break;
			default:
				$item_template = 'post';
		}

		ob_start();
		if ( $wp_query->have_posts() ) : 
			$number = $wp_query->post_count;
			
			$container_classes = array('vice-elementor-owl-carousel-container');
			set_query_var( 'animation_3d', $animation_3d );
			?>

			<div id="<?php echo esc_attr($grid_id); ?>" class="<?php echo esc_attr( implode(' ', $container_classes)); ?>">
				<div id="<?php echo esc_attr($el_id); ?>" class="vice-elementor-owl-carousel owl-carousel owl-theme vice-elementor-owl-theme" 
					data-items="<?php 				echo esc_attr($items_per_row_desktop); ?>"
					data-items_tablet="<?php 		echo esc_attr($items_per_row_tablet); ?>"
					data-items_mobile="<?php 		echo esc_attr($items_per_row_mobile); ?>"
					data-items_mobile_hori="2"
					data-gap="<?php 				echo esc_attr($gap); ?>"
					data-pause_on_hover="<?php 		echo esc_attr($pause_on_hover); ?>"
					data-loop="<?php 				echo esc_attr($loop); ?>" 
					data-center="<?php 				echo esc_attr($center); ?>" 
					data-stage_padding="<?php 		echo esc_attr($stage_padding); ?>"
					data-nav="<?php 				echo esc_attr($nav); ?>"
					data-dots="<?php 				echo esc_attr($dots); ?>" 
					data-autoplay_timeout="<?php 	echo esc_attr($autoplay_timeout); ?>" 
					data-amount="<?php echo esc_attr( $number ); ?>">
					<?php  
					/**
					 * Loop
					 */
					while ( $wp_query->have_posts() ) : $wp_query->the_post();
						$post = $wp_query->post;
						setup_postdata( $post );
						?>
						<div class="vice-elementor-item">
							<div class="vice-elementor-itemcontainer">
								<?php 
								get_template_part ( 'template-parts/post/'.$item_template );
								?>
							</div>
						</div>
						<?php
					endwhile;
					?>
				</div>
			</div>
			<?php
		else: 
			esc_html_e("Sorry, there is nothing for the moment.", "vice");
		endif; 
		wp_reset_postdata();
		return ob_get_clean();
	}
}