<?php
/**
 * @source  https://developers.elementor.com/elementor-controls/
 * @author  Vice
 * @package  Elementor Vice
 * @version  1.0.0
 */



namespace ViceElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once( __DIR__ . '/post-modernslider-function.php' );
class ViceElementorPostModernSlider extends Widget_Base {
	public function get_name() {
		return 'vice-elementor-post-modernslider'; // need to use same ID in the script js
	}
	public function get_title() {
		return esc_html__( 'Modern Slider', 'vice-elementor' );
	}
	public function get_icon() {
		return 'vice-elementor-icons icon-prel-post-carouse';
	}
	public function get_categories() {
		return [ 'aaa-vice' ]; // needs to be registered in _plugin.php
	}
	public function __construct($data = [], $args = null) {
      parent::__construct($data, $args);
      wp_register_script( 'vice-elementor-post-modernslider', plugins_url( '/post-modernslider.js', __FILE__ ), [ 'elementor-frontend' ], '1.0.0', true );
   	}
 	public function get_script_depends() {
	     return [ 'vice-elementor-post-modernslider' ];
	}
	protected function register_controls() {

		/**
		 * ======================================
		 * Section:
		 * Query parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'vice_elementor_section_query_global',
			[
				'label' => esc_html__( 'Content', 'vice-elementor' ),
			]
		);
			$this->add_control(
				'post_type',
				[
					'label' => esc_html__( 'Post type', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						"post" => esc_html__( "Post", 'vice' ),
						"podcast" => esc_html__( "Podcast", 'vice' ),
						'event' => esc_html__( "Event", 'vice' ),
						'artist' => esc_html__( "Artist", 'vice' ),
						'release' => esc_html__( "Release", 'vice' ),
					]
				]
			);

			$this->add_control(
				'query_event_filter',
				[
					'label' => esc_html__( 'Event filter', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'multiple' => false,
					'options' =>[
						false => esc_html__( 'Any event', 'vice' ),
						'past' => esc_html__( 'Past events', 'vice' ),
						'next' => esc_html__( 'Next events', 'vice' ),
					],
					'condition' => [
						'post_type' => 'event',
					],
				]
			);


			$this->add_control(
				'tax_filter',
				[
					'label' => esc_html__( 'Category filters', 'vice-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => vice_elementor_get_terms_array()
				]
			);
		// Important::::::::::::::::::::::::::::::::::::
		// Fields added by query-fields.php
		// :::::::::::::::::::::::::::::::::::::::::::::
		$this->end_controls_section();
		
		/**
		 * ======================================
		 * Section:
		 * 3DSlider parameters
		 * ======================================
		 */
		$this->start_controls_section(
			'vice_elementor_section_modernslider',
			[
				'label' => esc_html__( 'Settings', 'vice-elementor' ),
			]
		);
		$this->add_control(
			'autoplay_timeout',
			[
				'label' => esc_html__( 'Autoplay timeout', 'vice-elementor' ),
				'description' => esc_html__( '0 = disabled', 'vice-elementor' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 80000,
				'step' => 1000,
				'default' => 4000
			]
		);
		$this->add_control(
			'pause_on_hover',
			[
				'label' => esc_html__( 'Pause on hover', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'true',
				'return_value' => 'true',
			]
		);
		$this->add_control(
			'loop',
			[
				'label' => esc_html__( 'Loop', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'true',
				'return_value' => 'true',
			]
		);
		
		$this->add_control(
			'nav',
			[
				'label' => esc_html__( 'Arrows', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'vice-elementor' ),
				'label_off' => esc_html__('Hide', 'vice-elementor' ),
				'return_value' => 'true',
				'default' => 'true'
			]
		);
		$this->add_control(
			'dots',
			[
				'label' => esc_html__( 'Dots', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'vice-elementor' ),
				'label_off' => esc_html__('Hide', 'vice-elementor' ),
				'return_value' => 'true',
				'default' => 'true'
			]
		);
		$this->add_control(
			'vice_fx',
			[
				'label' => esc_html__( 'Effect', 'vice-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'multiple' => false,
				'options' =>[
					'default' =>	esc_html__( "None", 'vice-elementor' ),
					"glitch" =>	esc_html__( "Glitch", 'vice-elementor' ),
				]
			]
		);

		$this->add_control(
			'animation_3d',
			[
				'label' => esc_html__( '3D animation', 'vice-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Yes', 'vice-elementor' ),
				'label_off' => esc_html__('No', 'vice-elementor' ),
				'return_value' => 'true',
				'default' => false
			]
		);


		$this->end_controls_section();




		

		
	}
	/**
	 * Frontend
	 */
	protected function render() {
		$atts = $this->get_settings_for_display();
		if(array_key_exists('tax_filter', $atts)){
			if(is_array($atts['tax_filter'])) {
				$atts['tax_filter'] = implode(',', $atts['tax_filter']);
			}
		}
		if(function_exists('vice_template_post_modernslider')){
			echo vice_template_post_modernslider( $atts );
		}
	}
	protected function content_template() {}
}